@@ -19,7 +19,7 @@ require 5.008;
 
 # Use perl 5.8's feature of using a scalar as a filehandle.
 my   $fh;
-my   $str;
+my   $str = '';
 open $fh, '>', \$str or die "Failed to open filehandle: $!";;
 
 
