@@ -7,7 +7,7 @@ package Spreadsheet::WriteExcel::BIFFwriter;
 #
 # Used in conjunction with Spreadsheet::WriteExcel
 #
-# Copyright 2000-2005, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2008, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -24,7 +24,7 @@ use strict;
 use vars qw($VERSION @ISA);
 @ISA = qw(Exporter);
 
-$VERSION = '2.01';
+$VERSION = '2.20';
 
 ###############################################################################
 #
@@ -45,10 +45,11 @@ sub new {
     my $class  = $_[0];
 
     my $self   = {
-                    _byte_order    => '',
-                    _data          => '',
-                    _datasize      => 0,
-                    _limit         => 8224,
+                    _byte_order      => '',
+                    _data            => '',
+                    _datasize        => 0,
+                    _limit           => 8224,
+                    _ignore_continue => 0,
                  };
 
     bless $self, $class;
@@ -107,6 +108,8 @@ sub _prepend {
 
     $self->{_data}      = $data . $self->{_data};
     $self->{_datasize} += length($data);
+
+    return $data;
 }
 
 
@@ -125,6 +128,8 @@ sub _append {
 
     $self->{_data}      = $self->{_data} . $data;
     $self->{_datasize} += length($data);
+
+    return $data;
 }
 
 
@@ -192,16 +197,21 @@ sub _store_eof {
 # This function take a long BIFF record and inserts CONTINUE records as
 # necessary.
 #
+# Some records have their own specialised Continue blocks so there is also an
+# option to bypass this function.
+#
 sub _add_continue {
 
     my $self        = shift;
     my $data        = $_[0];
     my $limit       = $self->{_limit};
     my $record      = 0x003C; # Record identifier
-    my $length;               # Number of bytes to follow
     my $header;
     my $tmp;
 
+    # Skip this if another method handles the continue blocks.
+    return $data if $self->{_ignore_continue};
+
     # The first 2080/8224 bytes remain intact. However, we have to change
     # the length field of the record.
     #
@@ -223,6 +233,36 @@ sub _add_continue {
     return $tmp ;
 }
 
+
+###############################################################################
+#
+# _add_mso_generic()
+#
+# Create a mso structure that is part of an Escher drawing object. These are
+# are used for images, comments and filters. This generic method is used by
+# other methods to create specific mso records.
+#
+# Returns the packed record.
+#
+sub _add_mso_generic {
+
+    my $self        = shift;
+    my $type        = $_[0];
+    my $version     = $_[1];
+    my $instance    = $_[2];
+    my $data        = $_[3];
+    my $length      = defined $_[4] ? $_[4] : length($data);
+
+    # The header contains version and instance info packed into 2 bytes.
+    my $header      = $version | ($instance << 4);
+
+    my $record      = pack "vvV", $header, $type, $length;
+       $record     .= $data;
+
+    return $record;
+}
+
+
 ###############################################################################
 #
 # For debugging
@@ -270,6 +310,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMV, John McNamara.
+ MM-MMVIII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
