@@ -7,7 +7,7 @@ package Spreadsheet::WriteExcel::Big;
 # Spreadsheet::WriteExcel - Write formatted text and numbers to a
 # cross-platform Excel binary file.
 #
-# Copyright 2000-2006, John McNamara.
+# Copyright 2000-2008, John McNamara.
 #
 #
 
@@ -22,7 +22,7 @@ use Spreadsheet::WriteExcel::WorkbookBig;
 use vars qw($VERSION @ISA);
 @ISA = qw(Spreadsheet::WriteExcel::WorkbookBig Exporter);
 
-$VERSION = '2.01'; # May 2000
+$VERSION = '2.20';
 
 ###############################################################################
 #
@@ -60,14 +60,17 @@ Big - A class for creating Excel files > 7MB.
 
 =head1 SYNOPSIS
 
-
-See the documentation for Spreadsheet::WriteExcel.
+The direct use of this module is deprecated. See below.
 
 
 =head1 DESCRIPTION
 
+The module is a sub-class of Spreadsheet::WriteExcel used for creating Excel files greater than 7MB.
+
+Direct use of this module is deprecated. As of version 2.17 Spreadsheet::WriteExcel can create files larger than 7MB if OLE::Storage_Lite is installed.
+
+This module only exists for backwards compatibility.
 
-This module is used in conjunction with Spreadsheet::WriteExcel.
 
     use Spreadsheet::WriteExcel::Big;
 
@@ -81,7 +84,7 @@ This module is used in conjunction with Spreadsheet::WriteExcel.
 
 =head1 REQUIREMENTS
 
-IO::Stringy and OLE::Storage_Lite
+OLE::Storage_Lite
 
 
 =head1 AUTHOR
@@ -93,7 +96,7 @@ John McNamara jmcnamara@cpan.org
 =head1 COPYRIGHT
 
 
- MM-MMVI, John McNamara.
+ MM-MMVIII, John McNamara.
 
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
