@@ -7,14 +7,14 @@ package Spreadsheet::WriteExcel::Format;
 #
 # Used in conjunction with Spreadsheet::WriteExcel
 #
-# Copyright 2000-2005, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2008, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
 
 use Exporter;
 use strict;
-use Carp; # TODO required?
+use Carp;
 
 
 
@@ -24,7 +24,7 @@ use Carp; # TODO required?
 use vars qw($AUTOLOAD $VERSION @ISA);
 @ISA = qw(Exporter);
 
-$VERSION = '2.04';
+$VERSION = '2.20';
 
 ###############################################################################
 #
@@ -39,6 +39,7 @@ sub new {
     my $self   = {
                     _xf_index       => shift || 0,
 
+                    _type           => 0,
                     _font_index     => 0,
                     _font           => 'Arial',
                     _size           => 10,
@@ -90,6 +91,8 @@ sub new {
                     _diag_color     => 0x40,
                     _diag_border    => 0,
 
+                    _font_only      => 0,
+
                     # Temp code to prevent merged formats in non-merged cells.
                     _used_merge     => 0,
 
@@ -117,9 +120,17 @@ sub copy {
     return unless defined $other;
     return unless (ref($self) eq ref($other));
 
-    my $xf = $self->{_xf_index};    # Store XF index assigned by Workbook.pm
-    %$self = %$other;               # Copy properties
-    $self->{_xf_index} = $xf;       # Restore XF index
+    # Store the properties that we don't want overwritten.
+    my $xf                  = $self->{_xf_index};
+    my $merge_range         = $self->{_merge_range};
+    my $used_merge          = $self->{_used_merge};
+
+    %$self                  = %$other; # Copy properties
+
+    # Restore saved properties.
+    $self->{_xf_index}      = $xf;
+    $self->{_merge_range}   = $merge_range;
+    $self->{_used_merge}    = $used_merge;
 }
 
 
@@ -144,13 +155,13 @@ sub get_xf {
     my $align;      # Alignment
     my $indent;     #
     my $icv;        # fg and bg pattern colors
-    my $border1;    # Border line style and color
-    my $border2;    # Border TODO
-    my $border3;    # Border TODO
+    my $border1;    # Border line options
+    my $border2;    # Border line options
+    my $border3;    # Border line options
 
 
     # Set the type of the XF record and some of the attributes.
-    if ($_[0] eq "style") {
+    if ($self->{_type} == 0xFFF5) {
         $style = 0xFFF5;
     }
     else {
@@ -185,6 +196,25 @@ sub get_xf {
                        $self->{_locked}         != 1) ? 1 : 0;
 
 
+    # Set attribute changed flags for the style formats.
+    if ($self->{_xf_index} != 0 and $self->{_type} == 0xFFF5) {
+
+        if ($self->{_xf_index} >= 16) {
+            $atr_num    = 0;
+            $atr_fnt    = 1;
+        }
+        else {
+            $atr_num    = 1;
+            $atr_fnt    = 0;
+        }
+
+        $atr_alc    = 1;
+        $atr_bdr    = 1;
+        $atr_pat    = 1;
+        $atr_prot   = 1;
+    }
+
+
     # Set a default diagonal border style if none was specified.
     $self->{_diag_border} = 1 if !$self->{_diag_border} and $self->{_diag_type};
 
@@ -340,7 +370,7 @@ sub get_font {
     $rgch       = $self->{_font};
     $encoding   = $self->{_font_encoding};
 
-    # Handle utf8 strings in newer perls.
+    # Handle utf8 strings in perl 5.8.
     if ($] >= 5.008) {
         require Encode;
 
@@ -375,7 +405,7 @@ sub get_font {
                                       $sss, $uls, $bFamily,
                                       $bCharSet, $reserved, $cch, $encoding);
 
-    return($header . $data. $self->{_font});
+    return($header . $data . $rgch);
 }
 
 ###############################################################################
@@ -441,6 +471,7 @@ sub _get_color {
                     lime    => 0x0B,
                     navy    => 0x12,
                     orange  => 0x35,
+                    pink    => 0x21,
                     purple  => 0x14,
                     red     => 0x0A,
                     silver  => 0x16,
@@ -468,6 +499,26 @@ sub _get_color {
 }
 
 
+###############################################################################
+#
+# set_type()
+#
+# Set the XF object type as 0 = cell XF or 0xFFF5 = style XF.
+#
+sub set_type {
+
+    my $self = shift;
+    my $type = $_[0];
+
+    if (defined $_[0] and $_[0] eq 0) {
+        $self->{_type} = 0x0000;
+    }
+    else {
+        $self->{_type} = 0xFFF5;
+    }
+}
+
+
 ###############################################################################
 #
 # set_align()
@@ -659,26 +710,10 @@ sub set_properties {
         # Strip leading "-" from Tk style properties e.g. -color => 'red'.
         $key =~ s/^-//;
 
-
-        # Make sure method names are alphanumeric characters only, in case
-        # tainted data is passed to the eval().
-        #
-        die "Unknown method: \$self->set_$key\n" if $key =~ /\W/;
-
-
-        # Evaling all $values as a strings gets around the problem of some
-        # numerical format strings being evaluated as numbers, for example
-        # "00000" for a zip code.
-        #
-        if (defined $value) {
-            eval "\$self->set_$key('$value')";
-        }
-        else {
-            eval "\$self->set_$key(undef)";
-        }
-
-        die $@ if $@; # Rethrow the eval error.
-    }
+        # Create a sub to set the property.
+        my $sub = \&{"set_$key"};
+        $sub->($self, $value);
+   }
 }
 
 
@@ -720,9 +755,9 @@ sub AUTOLOAD {
         $value =  _get_color($_[0]);
 
         *{$AUTOLOAD} = sub {
-                             my $self  = shift;
+                                my $self  = shift;
 
-                             $self->{$attribute} = _get_color($_[0]);
+                                $self->{$attribute} = _get_color($_[0]);
                            };
     }
     else {
@@ -731,13 +766,13 @@ sub AUTOLOAD {
         $value = 1 if not defined $value; # The default value is always 1
 
         *{$AUTOLOAD} = sub {
-                             my $self  = shift;
-                             my $value = shift;
+                                my $self  = shift;
+                                my $value = shift;
 
-                             $value = 1 if not defined $value;
-    $self->{$attribute} = $value;
-                           };
-}
+                                $value = 1 if not defined $value;
+                                $self->{$attribute} = $value;
+                            };
+    }
 
 
     $self->{$attribute} = $value;
@@ -768,6 +803,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMV, John McNamara.
+ MM-MMVIII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
