@@ -7,7 +7,7 @@ package Spreadsheet::WriteExcel::OLEwriter;
 #
 # Used in conjunction with Spreadsheet::WriteExcel
 #
-# Copyright 2000-2006, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2008, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -24,7 +24,7 @@ use FileHandle;
 use vars qw($VERSION @ISA);
 @ISA = qw(Exporter);
 
-$VERSION = '2.15';
+$VERSION = '2.20';
 
 ###############################################################################
 #
@@ -172,7 +172,7 @@ sub close {
     $self->_write_property_storage() if not $self->{_biff_only};
     $self->_write_big_block_depot()  if not $self->{_biff_only};
 
-    my $close;
+    my $close = 1; # Default to no error for external filehandles.
 
     # Close the filehandle if it was created internally.
     $close = CORE::close($self->{_filehandle}) if $self->{_internal_fh};
@@ -193,6 +193,8 @@ sub DESTROY {
 
     my $self = shift;
 
+    local ($@, $!, $^E, $?);
+
     $self->close() unless $self->{_fileclosed};
 }
 
@@ -442,6 +444,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMVI, John McNamara.
+ MM-MMVIII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
